@@ -964,7 +964,11 @@ completion_list_add_plugins_commands_cb (const void *pointer, void *data,
     if (!completion->args)
         return WEECHAT_RC_OK;
 
-    argv = string_split (completion->args, " ", 0, 0, &argc);
+    argv = string_split (completion->args, " ",
+                         WEECHAT_STRING_SPLIT_STRIP_LEFT
+                         | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                         0, &argc);
     if (!argv)
         return WEECHAT_RC_OK;
 
@@ -1649,7 +1653,11 @@ completion_list_add_env_value_cb (const void *pointer, void *data,
 
     if (completion->args)
     {
-        argv = string_split (completion->args, " ", 0, 0, &argc);
+        argv = string_split (completion->args, " ",
+                             WEECHAT_STRING_SPLIT_STRIP_LEFT
+                             | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                             | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                             0, &argc);
         if (!argv)
             return WEECHAT_RC_OK;
 
