@@ -39,6 +39,9 @@
 #include "../plugins/plugin.h"
 
 
+char **input_commands_allowed = NULL;
+
+
 /*
  * Sends data to buffer input callback.
  */
@@ -54,10 +57,12 @@ input_exec_data (struct t_gui_buffer *buffer, const char *data)
                                         data);
     }
     else
+    {
         gui_chat_printf (buffer,
                          _("%sYou can not write text in this "
                            "buffer"),
                          gui_chat_prefix[GUI_CHAT_PREFIX_ERROR]);
+    }
 }
 
 /*
@@ -72,17 +77,43 @@ int
 input_exec_command (struct t_gui_buffer *buffer,
                     int any_plugin,
                     struct t_weechat_plugin *plugin,
-                    const char *string)
+                    const char *string,
+                    const char *commands_allowed)
 {
     char *command, *command_name, *pos;
+    char **old_commands_allowed, **new_commands_allowed;
     int rc;
 
     if ((!string) || (!string[0]))
         return WEECHAT_RC_ERROR;
 
+    rc = WEECHAT_RC_OK;
+
+    command = NULL;
+    command_name = NULL;
+
+    old_commands_allowed = input_commands_allowed;
+    new_commands_allowed = NULL;
+
     command = strdup (string);
     if (!command)
-        return WEECHAT_RC_ERROR;
+    {
+        rc = WEECHAT_RC_ERROR;
+        goto end;
+    }
+
+    if (commands_allowed)
+    {
+        new_commands_allowed = string_split (
+            commands_allowed,
+            ",",
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            NULL);
+        input_commands_allowed = new_commands_allowed;
+    }
 
     /* ignore spaces at the end of command */
     pos = &command[strlen (command) - 1];
@@ -99,12 +130,30 @@ input_exec_command (struct t_gui_buffer *buffer,
         string_strndup (command, pos - command) : strdup (command);
     if (!command_name)
     {
-        free (command);
-        return WEECHAT_RC_ERROR;
+        rc = WEECHAT_RC_ERROR;
+        goto end;
+    }
+
+    /* check if command is allowed */
+    if (input_commands_allowed
+        && !string_match_list (command_name + 1,
+                               (const char **)input_commands_allowed, 0))
+    {
+        if (weechat_debug_core >= 1)
+        {
+            gui_chat_printf_date_tags (
+                NULL, 0, "command_forbidden," GUI_FILTER_TAG_NO_FILTER,
+                _("warning: the command \"%s\" is not currently allowed "
+                  "(command: \"%s\", buffer: \"%s\")"),
+                command_name,
+                command,
+                buffer->full_name);
+        }
+        rc = WEECHAT_RC_ERROR;
+        goto end;
     }
 
     /* execute command */
-    rc = WEECHAT_RC_OK;
     switch (hook_command_exec (buffer, any_plugin, plugin, command))
     {
         case HOOK_COMMAND_EXEC_OK:
@@ -171,14 +220,21 @@ input_exec_command (struct t_gui_buffer *buffer,
             break;
     }
 
-    free (command);
-    free (command_name);
+end:
+    if (command)
+        free (command);
+    if (command_name)
+        free (command_name);
+
+    if (new_commands_allowed)
+        string_free_split (new_commands_allowed);
+    input_commands_allowed = old_commands_allowed;
 
     return rc;
 }
 
 /*
- * Reads user input and sends data to buffer's callback.
+ * Sends data to a buffer's callback.
  *
  * Returns:
  *   WEECHAT_RC_OK: data properly sent (or command executed successfully)
@@ -186,22 +242,27 @@ input_exec_command (struct t_gui_buffer *buffer,
  */
 
 int
-input_data (struct t_gui_buffer *buffer, const char *data)
+input_data (struct t_gui_buffer *buffer, const char *data,
+            const char *commands_allowed)
 {
     char *pos, *buf, str_buffer[128], *new_data, *buffer_full_name;
     const char *ptr_data, *ptr_data_for_buffer;
     int length, char_size, first_command, rc;
 
+    if (!buffer || !gui_buffer_valid (buffer) || !data)
+        return WEECHAT_RC_ERROR;
+
     rc = WEECHAT_RC_OK;
 
-    if (!buffer || !gui_buffer_valid (buffer) || !data)
-    {
-        return WEECHAT_RC_ERROR;
-    }
+    buffer_full_name = NULL;
+    new_data = NULL;
 
     buffer_full_name = strdup (buffer->full_name);
     if (!buffer_full_name)
-        return WEECHAT_RC_ERROR;
+    {
+        rc = WEECHAT_RC_ERROR;
+        goto end;
+    }
 
     /* execute modifier "input_text_for_buffer" */
     snprintf (str_buffer, sizeof (str_buffer),
@@ -267,7 +328,8 @@ input_data (struct t_gui_buffer *buffer, const char *data)
         else
         {
             /* input string is a command */
-            rc = input_exec_command (buffer, 1, buffer->plugin, ptr_data);
+            rc = input_exec_command (buffer, 1, buffer->plugin, ptr_data,
+                                     commands_allowed);
         }
 
         if (pos)
@@ -282,10 +344,106 @@ input_data (struct t_gui_buffer *buffer, const char *data)
     }
 
 end:
-    if (new_data)
-        free (new_data);
     if (buffer_full_name)
         free (buffer_full_name);
+    if (new_data)
+        free (new_data);
 
     return rc;
 }
+
+/*
+ * Callback for timer set by input_data_delayed.
+ */
+
+int
+input_data_timer_cb (const void *pointer, void *data, int remaining_calls)
+{
+    char **timer_args;
+    int i;
+    struct t_gui_buffer *ptr_buffer;
+
+    /* make C compiler happy */
+    (void) data;
+    (void) remaining_calls;
+
+    timer_args = (char **)pointer;
+
+    if (!timer_args)
+        return WEECHAT_RC_ERROR;
+
+    if (timer_args[0] && timer_args[1])
+    {
+        ptr_buffer = gui_buffer_search_by_full_name (timer_args[0]);
+        if (ptr_buffer)
+            (void) input_data (ptr_buffer, timer_args[1], timer_args[2]);
+    }
+
+    for (i = 0; i < 3; i++)
+    {
+        if (timer_args[i])
+            free (timer_args[i]);
+    }
+    free (timer_args);
+
+    return WEECHAT_RC_OK;
+}
+
+/*
+ * Sends data to a buffer's callback with an optional delay (in milliseconds).
+ *
+ * If delay < 1, the command is executed immediately.
+ * If delay >= 1, the command is scheduled for execution in this number of ms.
+ *
+ * Returns:
+ *   WEECHAT_RC_OK: data properly sent or scheduled for execution
+ *   WEECHAT_RC_ERROR: error
+ */
+
+int
+input_data_delayed (struct t_gui_buffer *buffer, const char *data,
+                    const char *commands_allowed, long delay)
+{
+    char **timer_args, *new_commands_allowed;
+
+    if (delay < 1)
+        return input_data (buffer, data, commands_allowed);
+
+    timer_args = malloc (3 * sizeof (*timer_args));
+    if (!timer_args)
+    {
+        gui_chat_printf (NULL,
+                         _("%sNot enough memory (%s)"),
+                         gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],
+                         "/wait");
+        return WEECHAT_RC_ERROR;
+    }
+
+    if (commands_allowed)
+    {
+        new_commands_allowed = strdup (commands_allowed);
+    }
+    else if (input_commands_allowed)
+    {
+        new_commands_allowed = string_build_with_split_string (
+            (const char **)input_commands_allowed, ",");
+    }
+    else
+    {
+        new_commands_allowed = NULL;
+    }
+
+    timer_args[0] = strdup (buffer->full_name);
+    timer_args[1] = strdup (data);
+    timer_args[2] = new_commands_allowed;
+
+    /* schedule command, execute it after "delay" milliseconds */
+    hook_timer (NULL,
+                (delay >= 1) ? delay : 1,
+                0,
+                1,
+                &input_data_timer_cb,
+                timer_args, NULL);
+
+    return WEECHAT_RC_OK;
+}
