@@ -57,6 +57,7 @@
 #include "wee-utf8.h"
 #include "../gui/gui-chat.h"
 #include "../gui/gui-window.h"
+#include "../plugins/plugin.h"
 
 
 #ifdef HAVE_SYS_RESOURCE_H
@@ -205,8 +206,11 @@ util_setrlimit ()
     int num_items, i;
     long number;
 
-    items = string_split (CONFIG_STRING(config_startup_sys_rlimit), ",", 0, 0,
-                          &num_items);
+    items = string_split (CONFIG_STRING(config_startup_sys_rlimit), ",",
+                          WEECHAT_STRING_SPLIT_STRIP_LEFT
+                          | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                          | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                          0, &num_items);
     if (items)
     {
         for (i = 0; i < num_items; i++)
@@ -334,6 +338,78 @@ util_get_time_string (const time_t *date)
     return text_time;
 }
 
+/*
+ * Parses a string with a delay and optional unit, returns the delay in
+ * milliseconds.
+ *
+ * The delay is a number followed by a unit which can be:
+ *   - "ms": milliseconds
+ *   - "s": seconds
+ *   - "m": minutes
+ *   - "h": hours
+ *
+ * The default factor sets the default unit:
+ *   - 1: milliseconds
+ *   - 1000: seconds
+ *   - 60000: minutes
+ *   - 3600000: hours
+ *
+ * Returns the delay in milliseconds, -1 if error.
+ */
+
+long
+util_parse_delay (const char *string_delay, long default_factor)
+{
+    const char *pos;
+    char *str_number, *error;
+    long factor, delay;
+
+    if (!string_delay || !string_delay[0] || (default_factor < 1))
+        return -1;
+
+    factor = default_factor;
+
+    pos = string_delay;
+    while (pos[0] && isdigit ((unsigned char)pos[0]))
+    {
+        pos++;
+    }
+
+    if ((pos > string_delay) && pos[0])
+    {
+        str_number = string_strndup (string_delay, pos - string_delay);
+        if (strcmp (pos, "ms") == 0)
+            factor = 1;
+        else if (strcmp (pos, "s") == 0)
+            factor = 1000;
+        else if (strcmp (pos, "m") == 0)
+            factor = 1000 * 60;
+        else if (strcmp (pos, "h") == 0)
+            factor = 1000 * 60 * 60;
+        else
+            return -1;
+    }
+    else
+    {
+        str_number = strdup (string_delay);
+    }
+
+    if (!str_number)
+        return -1;
+
+    error = NULL;
+    delay = strtol (str_number, &error, 10);
+    if (!error || error[0] || (delay < 0))
+    {
+        free (str_number);
+        return -1;
+    }
+
+    free (str_number);
+
+    return delay * factor;
+}
+
 /*
  * Gets a signal number with a name; only some commonly used signal names are
  * supported here (see declaration of util_signals[]).
@@ -346,6 +422,9 @@ util_signal_search (const char *name)
 {
     int i;
 
+    if (!name)
+        return -1;
+
     for (i = 0; util_signals[i].name; i++)
     {
         if (string_strcasecmp (util_signals[i].name, name) == 0)
@@ -858,7 +937,11 @@ util_version_number (const char *version)
     int num_items, i, version_int[4], index_buf;
     long number;
 
-    items = string_split (version, ".", 0, 4, &num_items);
+    items = string_split (version, ".",
+                          WEECHAT_STRING_SPLIT_STRIP_LEFT
+                          | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                          | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                          4, &num_items);
     for (i = 0; i < 4; i++)
     {
         version_int[i] = 0;
@@ -901,7 +984,7 @@ util_version_number (const char *version)
 }
 
 /*
- * Return uptime as number of days, hours, minutes, seconds.
+ * Returns uptime as number of days, hours, minutes, seconds.
  */
 
 void
