@@ -1,7 +1,7 @@
 /*
  * gui-completion.c - word completion according to context (used by all GUI)
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -431,6 +431,7 @@ gui_completion_list_add (struct t_gui_completion *completion, const char *word,
                           CONFIG_STRING(config_completion_nick_completer));
                 completion_word->word = strdup (buffer);
                 arraylist_insert (completion->list, index, completion_word);
+                completion->add_space = 0;
             }
             else
             {
@@ -560,7 +561,12 @@ gui_completion_get_matching_template (struct t_gui_completion *completion,
     for (i = 0; i < HOOK_COMMAND(hook_command, cplt_num_templates); i++)
     {
         items = string_split (HOOK_COMMAND(hook_command, cplt_templates_static)[i],
-                              "|", 0, 0, &num_items);
+                              "|",
+                              WEECHAT_STRING_SPLIT_STRIP_LEFT
+                              | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                              | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                              0,
+                              &num_items);
         if (items)
         {
             for (j = 0; j < num_items; j++)
