@@ -75,9 +75,9 @@ gui_filter_check_line (struct t_gui_line_data *line_data)
         if (ptr_filter->enabled)
         {
             /* check buffer */
-            if (gui_buffer_match_list_split (line_data->buffer,
-                                             ptr_filter->num_buffers,
-                                             ptr_filter->buffers))
+            if (string_match_list (line_data->buffer->full_name,
+                                   (const char **)ptr_filter->buffers,
+                                   0))
             {
                 if ((strcmp (ptr_filter->tags, "*") == 0)
                     || (gui_line_match_tags (line_data,
@@ -186,17 +186,25 @@ gui_filter_buffer (struct t_gui_buffer *buffer,
 
 /*
  * Filters all buffers, using message filters.
+ *
+ * If filter is NULL, filters all buffers.
+ * If filter is not NULL, filters only buffers matched by this filter.
  */
 
 void
-gui_filter_all_buffers ()
+gui_filter_all_buffers (struct t_gui_filter *filter)
 {
     struct t_gui_buffer *ptr_buffer;
 
     for (ptr_buffer = gui_buffers; ptr_buffer;
          ptr_buffer = ptr_buffer->next_buffer)
     {
-        gui_filter_buffer (ptr_buffer, NULL);
+        if (!filter
+            || string_match_list (ptr_buffer->full_name,
+                                  (const char **)filter->buffers, 0))
+        {
+            gui_filter_buffer (ptr_buffer, NULL);
+        }
     }
 }
 
@@ -210,7 +218,7 @@ gui_filter_global_enable ()
     if (!gui_filters_enabled)
     {
         gui_filters_enabled = 1;
-        gui_filter_all_buffers ();
+        gui_filter_all_buffers (NULL);
         (void) hook_signal_send ("filters_enabled",
                                  WEECHAT_HOOK_SIGNAL_STRING, NULL);
     }
@@ -226,7 +234,7 @@ gui_filter_global_disable ()
     if (gui_filters_enabled)
     {
         gui_filters_enabled = 0;
-        gui_filter_all_buffers ();
+        gui_filter_all_buffers (NULL);
         (void) hook_signal_send ("filters_disabled",
                                  WEECHAT_HOOK_SIGNAL_STRING, NULL);
     }
@@ -294,7 +302,9 @@ gui_filter_new (int enabled, const char *name, const char *buffer_name,
     if (gui_filter_search_by_name (name))
     {
         gui_filter_new_error (name,
-                              _("a filter with same name already exists"));
+                              _("a filter with same name already exists "
+                                "(choose another name or use option "
+                                "\"addreplace\" to overwrite it)"));
         return NULL;
     }
 
@@ -385,9 +395,14 @@ gui_filter_new (int enabled, const char *name, const char *buffer_name,
         new_filter->enabled = enabled;
         new_filter->name = strdup (name);
         new_filter->buffer_name = strdup ((buffer_name) ? buffer_name : "*");
-        new_filter->buffers = string_split (new_filter->buffer_name,
-                                            ",", 0, 0,
-                                            &new_filter->num_buffers);
+        new_filter->buffers = string_split (
+            new_filter->buffer_name,
+            ",",
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            &new_filter->num_buffers);
         new_filter->tags = (tags) ? strdup (tags) : NULL;
         new_filter->tags_array = string_split_tags (new_filter->tags,
                                                     &new_filter->tags_count);
