@@ -1491,9 +1491,20 @@ fset_option_config_timer_cb (const void *pointer,
     (void) data;
     (void) remaining_calls;
 
-    weechat_hashtable_map (fset_option_timer_options_changed,
-                           &fset_option_timer_option_changed_cb,
-                           NULL);
+    if (weechat_hashtable_get_integer (
+            fset_option_timer_options_changed,
+            "items_count") >= FSET_OPTION_TIMER_MAX_OPTIONS_CHANGED)
+    {
+        fset_option_get_options ();
+        fset_buffer_refresh (1);
+    }
+    else
+    {
+        weechat_hashtable_map (fset_option_timer_options_changed,
+                               &fset_option_timer_option_changed_cb,
+                               NULL);
+    }
+
     weechat_hashtable_remove_all (fset_option_timer_options_changed);
 
     fset_option_timer_hook = NULL;
@@ -1511,7 +1522,7 @@ fset_option_config_cb (const void *pointer,
                        const char *option,
                        const char *value)
 {
-    const char *ptr_info;
+    char *info;
 
     /* make C compiler happy */
     (void) pointer;
@@ -1523,12 +1534,27 @@ fset_option_config_cb (const void *pointer,
         return WEECHAT_RC_OK;
 
     /* do nothing if WeeChat is upgrading */
-    ptr_info = weechat_info_get ("weechat_upgrading", NULL);
-    if (ptr_info && (strcmp (ptr_info, "1") == 0))
+    info = weechat_info_get ("weechat_upgrading", NULL);
+    if (info && (strcmp (info, "1") == 0))
+    {
+        free (info);
         return WEECHAT_RC_OK;
+    }
+    if (info)
+        free (info);
 
-    weechat_hashtable_set (fset_option_timer_options_changed,
-                           option, NULL);
+    /*
+     * we limit the number of options to display with the timer; for example
+     * on /reload, many options are changed, so we'll get all options and
+     * display them, instead of change them one by one, which is very slow
+     */
+    if (weechat_hashtable_get_integer (
+            fset_option_timer_options_changed,
+            "items_count") < FSET_OPTION_TIMER_MAX_OPTIONS_CHANGED)
+    {
+        weechat_hashtable_set (fset_option_timer_options_changed,
+                               option, NULL);
+    }
 
     if (!fset_option_timer_hook)
     {
