@@ -118,9 +118,9 @@ enum t_irc_server_option
 #define IRC_SERVER_NUM_OUTQUEUES_PRIO 2
 
 /* flags for irc_server_sendf() */
-#define IRC_SERVER_SEND_OUTQ_PRIO_HIGH   1
-#define IRC_SERVER_SEND_OUTQ_PRIO_LOW    2
-#define IRC_SERVER_SEND_RETURN_HASHTABLE 4
+#define IRC_SERVER_SEND_OUTQ_PRIO_HIGH   (1 << 0)
+#define IRC_SERVER_SEND_OUTQ_PRIO_LOW    (1 << 1)
+#define IRC_SERVER_SEND_RETURN_HASHTABLE (1 << 2)
 
 /* version strings */
 #define IRC_SERVER_VERSION_CAP "302"
@@ -192,6 +192,7 @@ struct t_irc_server
                                     /* (nick____1, nick____2, ...)           */
     char *nick;                     /* current nickname                      */
     char *nick_modes;               /* nick modes                            */
+    char *host;                     /* self host (set if known)              */
     int checking_cap_ls;            /* 1 if checking supported capabilities  */
     struct t_hashtable *cap_ls;     /* list of supported capabilities        */
     int checking_cap_list;          /* 1 if checking enabled capabilities    */
@@ -290,8 +291,12 @@ extern int irc_server_sasl_enabled (struct t_irc_server *server);
 extern char *irc_server_get_name_without_port (const char *name);
 extern int irc_server_set_addresses (struct t_irc_server *server,
                                      const char *addresses);
-extern void irc_server_set_nicks (struct t_irc_server *server, const char *nicks);
-extern void irc_server_set_nick (struct t_irc_server *server, const char *nick);
+extern void irc_server_set_nicks (struct t_irc_server *server,
+                                  const char *nicks);
+extern void irc_server_set_nick (struct t_irc_server *server,
+                                 const char *nick);
+extern void irc_server_set_host (struct t_irc_server *server,
+                                 const char *host);
 extern const char *irc_server_get_alternate_nick (struct t_irc_server *server);
 extern const char *irc_server_get_isupport_value (struct t_irc_server *server,
                                                   const char *feature);
