@@ -420,6 +420,9 @@ irc_upgrade_read_cb (const void *pointer, void *data,
                     str = weechat_infolist_string (infolist, "nick_modes");
                     if (str)
                         irc_upgrade_current_server->nick_modes = strdup (str);
+                    str = weechat_infolist_string (infolist, "host");
+                    if (str)
+                        irc_upgrade_current_server->host = strdup (str);
                     /*
                      * "cap_ls" and "cap_list" replace "cap_away_notify",
                      * "cap_account_notify" and "cap_extended_join"
@@ -549,8 +552,14 @@ irc_upgrade_read_cb (const void *pointer, void *data,
                         str = weechat_infolist_string (infolist, "join_msg_received");
                         if (str)
                         {
-                            items = weechat_string_split (str, ",", 0, 0,
-                                                          &num_items);
+                            items = weechat_string_split (
+                                str,
+                                ",",
+                                WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                0,
+                                &num_items);
                             if (items)
                             {
                                 for (i = 0; i < num_items; i++)
@@ -605,8 +614,14 @@ irc_upgrade_read_cb (const void *pointer, void *data,
                         str = weechat_infolist_string (infolist, "join_smart_filtered");
                         if (str)
                         {
-                            nicks = weechat_string_split (str, ",", 0, 0,
-                                                          &nicks_count);
+                            nicks = weechat_string_split (
+                                str,
+                                ",",
+                                WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                0,
+                                &nicks_count);
                             if (nicks)
                             {
                                 for (i = 0; i < nicks_count; i++)
