@@ -196,7 +196,7 @@ plugin_check_extension_allowed (const char *filename)
 int
 plugin_check_autoload (const char *filename)
 {
-    int i, plugin_authorized, plugin_forbidden, length, length_ext;
+    int i, length, length_ext, match;
     char *full_name, *ptr_base_name, *base_name, *plugin_name;
 
     /* by default we can auto load all plugins */
@@ -252,33 +252,13 @@ plugin_check_autoload (const char *filename)
     if (!plugin_name)
         return 1;
 
-    /* browse array and check if plugin is authorized or forbidden */
-    plugin_authorized = 0;
-    plugin_forbidden = 0;
-    for (i = 0; i < plugin_autoload_count; i++)
-    {
-        if (plugin_autoload_array[i][0] == '!')
-        {
-            /*
-             * negative value: it is used to prevent a plugin from loading
-             * for example with "*,!perl", all plugins are loaded, but not perl
-             */
-            if (string_match (plugin_name, plugin_autoload_array[i] + 1, 0))
-                plugin_forbidden = 1;
-        }
-        else
-        {
-            if (string_match (plugin_name, plugin_autoload_array[i], 0))
-                plugin_authorized = 1;
-        }
-    }
+    match = string_match_list (plugin_name,
+                               (const char **)plugin_autoload_array,
+                               0);
 
     free (plugin_name);
 
-    if (plugin_forbidden)
-        return 0;
-
-    return plugin_authorized;
+    return match;
 }
 
 /*
@@ -616,6 +596,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->strcasestr = &string_strcasestr;
         new_plugin->strlen_screen = &gui_chat_strlen_screen;
         new_plugin->string_match = &string_match;
+        new_plugin->string_match_list = &string_match_list;
         new_plugin->string_replace = &string_replace;
         new_plugin->string_expand_home = &string_expand_home;
         new_plugin->string_eval_path_home = &string_eval_path_home;
@@ -847,6 +828,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->bar_remove = &gui_bar_free;
 
         new_plugin->command = &plugin_api_command;
+        new_plugin->command_options = &plugin_api_command_options;
 
         new_plugin->network_pass_proxy = &network_pass_proxy;
         new_plugin->network_connect_to = &network_connect_to;
@@ -1022,9 +1004,14 @@ plugin_auto_load (char *force_plugin_autoload,
 
     if (ptr_plugin_autoload && ptr_plugin_autoload[0])
     {
-        plugin_autoload_array = string_split (ptr_plugin_autoload,
-                                              ",", 0, 0,
-                                              &plugin_autoload_count);
+        plugin_autoload_array = string_split (
+            ptr_plugin_autoload,
+            ",",
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            &plugin_autoload_count);
     }
 
     /* auto-load plugins in custom path */
