@@ -340,7 +340,10 @@ relay_client_recv_text (struct t_relay_client *client, const char *data)
         pos[0] = '\0';
 
         lines = weechat_string_split (client->partial_message, "\n",
-                                      0, 0, &num_lines);
+                                      WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                      | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                      | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                      0, &num_lines);
         if (lines)
         {
             for (i = 0; i < num_lines; i++)
@@ -1242,7 +1245,8 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
 #endif /* HAVE_GNUTLS */
         new_client->websocket = 0;
         new_client->http_headers = NULL;
-        new_client->address = strdup ((address) ? address : "?");
+        new_client->address = strdup ((address && address[0]) ?
+                                      address : "local");
         new_client->real_ip = NULL;
         new_client->status = RELAY_STATUS_CONNECTED;
         new_client->protocol = server->protocol;
@@ -1351,13 +1355,26 @@ relay_client_new (int sock, const char *address, struct t_relay_server *server)
             last_relay_client = new_client;
         relay_clients = new_client;
 
-        weechat_printf_date_tags (NULL, 0, "relay_client",
-                                  _("%s: new client on port %d: %s%s%s"),
-                                  RELAY_PLUGIN_NAME,
-                                  server->port,
-                                  RELAY_COLOR_CHAT_CLIENT,
-                                  new_client->desc,
-                                  RELAY_COLOR_CHAT);
+        if (server->unix_socket)
+        {
+            weechat_printf_date_tags (NULL, 0, "relay_client",
+                                      _("%s: new client on path %s: %s%s%s"),
+                                      RELAY_PLUGIN_NAME,
+                                      server->path,
+                                      RELAY_COLOR_CHAT_CLIENT,
+                                      new_client->desc,
+                                      RELAY_COLOR_CHAT);
+        }
+        else
+        {
+            weechat_printf_date_tags (NULL, 0, "relay_client",
+                                      _("%s: new client on port %s: %s%s%s"),
+                                      RELAY_PLUGIN_NAME,
+                                      server->path,
+                                      RELAY_COLOR_CHAT_CLIENT,
+                                      new_client->desc,
+                                      RELAY_COLOR_CHAT);
+        }
 
         new_client->hook_fd = weechat_hook_fd (new_client->sock,
                                                1, 0, 0,
