@@ -19,10 +19,15 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 #include <limits.h>
 #include <regex.h>
+#include <sys/un.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <errno.h>
 
 #include "../weechat-plugin.h"
 #include "relay.h"
@@ -36,6 +41,7 @@
 
 struct t_config_file *relay_config_file = NULL;
 struct t_config_section *relay_config_section_port = NULL;
+struct t_config_section *relay_config_section_path = NULL;
 
 /* relay config, look section */
 
@@ -75,6 +81,10 @@ struct t_config_option *relay_config_irc_backlog_since_last_message;
 struct t_config_option *relay_config_irc_backlog_tags;
 struct t_config_option *relay_config_irc_backlog_time_format;
 
+/* relay config, weechat section */
+
+struct t_config_option *relay_config_weechat_commands;
+
 /* other */
 
 regex_t *relay_config_regex_allowed_ips = NULL;
@@ -181,7 +191,7 @@ relay_config_change_network_ipv6_cb (const void *pointer, void *data,
     {
         relay_server_get_protocol_args (ptr_server->protocol_string,
                                         &ptr_server->ipv4, &ptr_server->ipv6,
-                                        NULL, NULL, NULL);
+                                        NULL, &ptr_server->unix_socket, NULL, NULL);
         relay_server_close_socket (ptr_server);
         relay_server_create_socket (ptr_server);
     }
@@ -303,6 +313,7 @@ relay_config_check_network_ssl_priorities (const void *pointer, void *data,
     return 0;
 #else
     /* make C compiler happy */
+    (void) pointer;
     (void) data;
     (void) option;
     (void) value;
@@ -400,7 +411,11 @@ relay_config_check_irc_backlog_tags (const void *pointer, void *data,
         return rc;
 
     /* split tags and check them */
-    tags = weechat_string_split (value, ",", 0, 0, &num_tags);
+    tags = weechat_string_split (value, ",",
+                                 WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                 | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                 | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                 0, &num_tags);
     if (tags)
     {
         for (i = 0; i < num_tags; i++)
@@ -444,8 +459,14 @@ relay_config_change_irc_backlog_tags (const void *pointer, void *data,
     else
         weechat_hashtable_remove_all (relay_config_hashtable_irc_backlog_tags);
 
-    items = weechat_string_split (weechat_config_string (relay_config_irc_backlog_tags),
-                                  ",", 0, 0, &num_items);
+    items = weechat_string_split (
+        weechat_config_string (relay_config_irc_backlog_tags),
+        ",",
+        WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+        0,
+        &num_items);
     if (items)
     {
         for (i = 0; i < num_items; i++)
@@ -494,6 +515,147 @@ relay_config_check_port_cb (const void *pointer, void *data,
     return 1;
 }
 
+/*
+ * Checks if a UNIX path is too long or empty.
+ *
+ * Returns:
+ *   1: path is valid
+ *   0: path is empty or too long
+ */
+
+int
+relay_config_check_path_length (const char *path)
+{
+    struct sockaddr_un addr;
+    size_t length, max_length;
+
+    length = strlen (path);
+    if (length == 0)
+    {
+        weechat_printf (NULL, _("%s%s: error: path is empty"),
+                        weechat_prefix ("error"), RELAY_PLUGIN_NAME);
+        return 0;
+    }
+
+    max_length = sizeof (addr.sun_path);
+    if (length + 1 > max_length)
+    {
+        weechat_printf (NULL,
+                        _("%s%s: error: path \"%s\" too long (length: %d; max: %d)"),
+                        weechat_prefix ("error"), RELAY_PLUGIN_NAME, path,
+                        length, max_length);
+        return 0;
+    }
+
+    return 1;
+}
+
+/*
+ * Checks if a UNIX path is available: it is available if not existing, or
+ * if a file of type socket already exists.
+ *
+ * Returns:
+ *    0: path is available
+ *   -1: path already exists and is not a socket
+ *   -2: invalid path
+ */
+
+int
+relay_config_check_path_available (const char *path)
+{
+    struct stat buf;
+    int rc;
+
+    rc = stat (path, &buf);
+
+    /* OK if an existing file is a socket */
+    if ((rc == 0) && S_ISSOCK(buf.st_mode))
+        return 0;
+
+    /* error if an existing file is NOT a socket */
+    if (rc == 0)
+        return -1;
+
+    /* OK if the file does not exist */
+    if (errno == ENOENT)
+        return 0;
+
+    /* on any other error, the path it considered as not available */
+    return -2;
+}
+
+/*
+ * Checks if a path is valid.
+ *
+ * Returns:
+ *   1: path is valid
+ *   0: path is not valid
+ */
+
+int
+relay_config_check_path_cb (const void *pointer, void *data,
+                            struct t_config_option *option,
+                            const char *value)
+{
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) option;
+
+    if (!relay_config_check_path_length (value))
+        return 0;
+
+    if (relay_server_search_path (value))
+    {
+        weechat_printf (NULL, _("%s%s: error: path \"%s\" is already used"),
+                        weechat_prefix ("error"), RELAY_PLUGIN_NAME, value);
+        return 0;
+    }
+
+    return 1;
+}
+
+/*
+ * Callback for changes on options in section "path".
+ */
+
+void
+relay_config_change_path_cb (const void *pointer, void *data,
+                             struct t_config_option *option)
+{
+    struct t_relay_server *ptr_server;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+
+    ptr_server = relay_server_search (weechat_config_option_get_pointer (option, "name"));
+    if (ptr_server)
+    {
+        relay_server_update_path (ptr_server,
+                                  (const char *)weechat_config_option_get_pointer (option, "value"));
+    }
+}
+
+/*
+ * Callback called when an option is deleted in section "path".
+ */
+
+void
+relay_config_delete_path_cb (const void *pointer, void *data,
+                             struct t_config_option *option)
+{
+    struct t_relay_server *ptr_server;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+
+    ptr_server = relay_server_search (weechat_config_option_get_pointer (option, "name"));
+    if (ptr_server)
+        relay_server_free (ptr_server);
+}
+
 /*
  * Callback for changes on options in section "port".
  */
@@ -536,17 +698,17 @@ relay_config_delete_port_cb (const void *pointer, void *data,
 }
 
 /*
- * Callback called when an option is created in section "port".
+ * Callback called when an option is created in section "port" or "path".
  */
 
 int
-relay_config_create_option_port (const void *pointer, void *data,
-                                 struct t_config_file *config_file,
-                                 struct t_config_section *section,
-                                 const char *option_name,
-                                 const char *value)
+relay_config_create_option_port_path (const void *pointer, void *data,
+                                      struct t_config_file *config_file,
+                                      struct t_config_section *section,
+                                      const char *option_name,
+                                      const char *value)
 {
-    int rc, protocol_number, ipv4, ipv6, ssl;
+    int rc, protocol_number, ipv4, ipv6, ssl, unix_socket;
     char *error, *protocol, *protocol_args;
     long port;
     struct t_relay_server *ptr_server;
@@ -561,7 +723,7 @@ relay_config_create_option_port (const void *pointer, void *data,
     port = -1;
 
     relay_server_get_protocol_args (option_name, &ipv4, &ipv6, &ssl,
-                                    &protocol, &protocol_args);
+                                    &unix_socket, &protocol, &protocol_args);
 
 #ifndef HAVE_GNUTLS
     if (ssl)
@@ -610,14 +772,32 @@ relay_config_create_option_port (const void *pointer, void *data,
 
     if (rc != WEECHAT_CONFIG_OPTION_SET_ERROR)
     {
-        error = NULL;
-        port = strtol (value, &error, 10);
-        ptr_server = relay_server_search_port ((int)port);
+        if (unix_socket)
+        {
+            ptr_server = relay_server_search_path (value);
+        }
+        else
+        {
+            error = NULL;
+            port = strtol (value, &error, 10);
+            ptr_server = relay_server_search_port ((int)port);
+        }
         if (ptr_server)
         {
-            weechat_printf (NULL, _("%s%s: error: port \"%d\" is already used"),
-                            weechat_prefix ("error"),
-                            RELAY_PLUGIN_NAME, (int)port);
+            if (unix_socket)
+            {
+                weechat_printf (NULL,
+                                _("%s%s: error: path \"%s\" is already used"),
+                                weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                                value);
+            }
+            else
+            {
+                weechat_printf (NULL,
+                                _("%s%s: error: port \"%d\" is already used"),
+                                weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                                (int)port);
+            }
             rc = WEECHAT_CONFIG_OPTION_SET_ERROR;
         }
     }
@@ -625,16 +805,33 @@ relay_config_create_option_port (const void *pointer, void *data,
     if (rc != WEECHAT_CONFIG_OPTION_SET_ERROR)
     {
         if (relay_server_new (option_name, protocol_number, protocol_args,
-                              port, ipv4, ipv6, ssl))
+                              port, value, ipv4, ipv6, ssl, unix_socket))
         {
             /* create configuration option */
-            weechat_config_new_option (
-                config_file, section,
-                option_name, "integer", NULL,
-                NULL, 0, 65535, "", value, 0,
-                &relay_config_check_port_cb, NULL, NULL,
-                &relay_config_change_port_cb, NULL, NULL,
-                &relay_config_delete_port_cb, NULL, NULL);
+            if (unix_socket)
+            {
+                weechat_config_new_option (
+                    config_file, section,
+                    option_name, "string",
+                    _("path to a socket file; \"%h\" at beginning of string "
+                      "is replaced by WeeChat home (\"~/.weechat\" by default), "
+                      "content is evaluated (see /help eval)"),
+                    NULL, 0, 0, "", value, 0,
+                    &relay_config_check_path_cb, NULL, NULL,
+                    &relay_config_change_path_cb, NULL, NULL,
+                    &relay_config_delete_path_cb, NULL, NULL);
+            }
+            else
+            {
+                weechat_config_new_option (
+                    config_file, section,
+                    option_name, "integer",
+                    _("port for relay"),
+                    NULL, 0, 65535, "", value, 0,
+                    &relay_config_check_port_cb, NULL, NULL,
+                    &relay_config_change_port_cb, NULL, NULL,
+                    &relay_config_delete_port_cb, NULL, NULL);
+            }
             rc = WEECHAT_CONFIG_OPTION_SET_OK_SAME_VALUE;
         }
         else
@@ -1003,6 +1200,37 @@ relay_config_init ()
         NULL, 0, 0, "[%H:%M] ", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 
+    /* section weechat */
+    ptr_section = weechat_config_new_section (relay_config_file, "weechat",
+                                              0, 0,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL,
+                                              NULL, NULL, NULL);
+    if (!ptr_section)
+    {
+        weechat_config_free (relay_config_file);
+        relay_config_file = NULL;
+        return 0;
+    }
+
+    relay_config_weechat_commands = weechat_config_new_option (
+        relay_config_file, ptr_section,
+        "commands", "string",
+        N_("comma-separated list of commands allowed/denied when input "
+           "data (text or command) is received from a client; "
+           "\"*\" means any command, a name beginning with \"!\" is "
+           "a negative value to prevent a command from being executed, "
+           "wildcard \"*\" is allowed in names; this option should be set if "
+           "the relay client is not safe (someone could use it to run "
+           "commands); for example \"*,!exec,!quit\" allows any command "
+           "except /exec and /quit"),
+        NULL, 0, 0, "", NULL, 0,
+        NULL, NULL, NULL,
+        NULL, NULL, NULL,
+        NULL, NULL, NULL);
+
     /* section port */
     ptr_section = weechat_config_new_section (
         relay_config_file, "port",
@@ -1010,7 +1238,7 @@ relay_config_init ()
         NULL, NULL, NULL,
         NULL, NULL, NULL,
         NULL, NULL, NULL,
-        &relay_config_create_option_port, NULL, NULL,
+        &relay_config_create_option_port_path, NULL, NULL,
         NULL, NULL, NULL);
     if (!ptr_section)
     {
@@ -1021,6 +1249,24 @@ relay_config_init ()
 
     relay_config_section_port = ptr_section;
 
+    /* section path */
+    ptr_section = weechat_config_new_section (
+        relay_config_file, "path",
+        1, 1,
+        NULL, NULL, NULL,
+        NULL, NULL, NULL,
+        NULL, NULL, NULL,
+        &relay_config_create_option_port_path, NULL, NULL,
+        NULL, NULL, NULL);
+    if (!ptr_section)
+    {
+        weechat_config_free (relay_config_file);
+        relay_config_file = NULL;
+        return 0;
+    }
+
+    relay_config_section_path = ptr_section;
+
     return 1;
 }
 
