@@ -26,6 +26,7 @@
 
 extern struct t_config_file *relay_config_file;
 extern struct t_config_section *relay_config_section_port;
+extern struct t_config_section *relay_config_section_path;
 
 extern struct t_config_option *relay_config_look_auto_open_buffer;
 extern struct t_config_option *relay_config_look_raw_messages;
@@ -57,6 +58,8 @@ extern struct t_config_option *relay_config_irc_backlog_since_last_message;
 extern struct t_config_option *relay_config_irc_backlog_tags;
 extern struct t_config_option *relay_config_irc_backlog_time_format;
 
+extern struct t_config_option *relay_config_weechat_commands;
+
 extern regex_t *relay_config_regex_allowed_ips;
 extern regex_t *relay_config_regex_websocket_allowed_origins;
 extern struct t_hashtable *relay_config_hashtable_irc_backlog_tags;
@@ -65,11 +68,13 @@ extern int relay_config_check_network_totp_secret (const void *pointer,
                                                    void *data,
                                                    struct t_config_option *option,
                                                    const char *value);
-extern int relay_config_create_option_port (const void *pointer, void *data,
-                                            struct t_config_file *config_file,
-                                            struct t_config_section *section,
-                                            const char *option_name,
-                                            const char *value);
+extern int relay_config_create_option_port_path (const void *pointer, void *data,
+                                                 struct t_config_file *config_file,
+                                                 struct t_config_section *section,
+                                                 const char *option_name,
+                                                 const char *value);
+extern int relay_config_check_path_length (const char *path);
+extern int relay_config_check_path_available (const char *path);
 extern int relay_config_init ();
 extern int relay_config_read ();
 extern int relay_config_write ();
