@@ -1,7 +1,7 @@
 /*
  * script-config.c - script configuration options (file script.conf)
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -96,7 +96,8 @@ struct t_config_option *script_config_scripts_url;
 const char *
 script_config_get_diff_command ()
 {
-    const char *diff_command, *dir_separator;
+    const char *diff_command;
+    char *dir_separator;
     static char result[64];
     struct stat st;
     char *path, **paths, bin[4096];
@@ -113,7 +114,11 @@ script_config_get_diff_command ()
         result[0] = '\0';
         if (dir_separator && path)
         {
-            paths = weechat_string_split (path, ":", 0, 0, &num_paths);
+            paths = weechat_string_split (path, ":",
+                                          WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                          | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                          | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                          0, &num_paths);
             if (paths)
             {
                 for (i = 0; i < num_paths; i++)
@@ -131,6 +136,8 @@ script_config_get_diff_command ()
                 weechat_string_free_split (paths);
             }
         }
+        if (dir_separator)
+            free (dir_separator);
         if (!result[0])
             snprintf (result, sizeof (result), "diff");
         return result;
@@ -289,8 +296,14 @@ script_config_hold (const char *name_with_extension)
     if (hold)
     {
         hold[0] = '\0';
-        items = weechat_string_split (weechat_config_string (script_config_scripts_hold),
-                                      ",", 0, 0, &num_items);
+        items = weechat_string_split (
+            weechat_config_string (script_config_scripts_hold),
+            ",",
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            &num_items);
         if (items)
         {
             for (i = 0; i < num_items; i++)
@@ -332,8 +345,14 @@ script_config_unhold (const char *name_with_extension)
     if (hold)
     {
         hold[0] = '\0';
-        items = weechat_string_split (weechat_config_string (script_config_scripts_hold),
-                                      ",", 0, 0, &num_items);
+        items = weechat_string_split (
+            weechat_config_string (script_config_scripts_hold),
+            ",",
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            &num_items);
         if (items)
         {
             for (i = 0; i < num_items; i++)
