@@ -733,7 +733,14 @@ trigger_callback_modifier_cb (const void *pointer, void *data,
                     pos2++;
                     if (pos2[0])
                     {
-                        tags = weechat_string_split (pos2, ",", 0, 0, &num_tags);
+                        tags = weechat_string_split (
+                            pos2,
+                            ",",
+                            WEECHAT_STRING_SPLIT_STRIP_LEFT
+                            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                            0,
+                            &num_tags);
                         length = 1 + strlen (pos2) + 1 + 1;
                         str_tags = malloc (length);
                         if (str_tags)
@@ -817,8 +824,11 @@ trigger_callback_line_cb (const void *pointer, void *data,
 
     weechat_hashtable_set (pointers, "buffer", buffer);
     ptr_value = weechat_hashtable_get (line, "tags");
-    tags = weechat_string_split ((ptr_value) ? ptr_value : "", ",", 0, 0,
-                                 &num_tags);
+    tags = weechat_string_split ((ptr_value) ? ptr_value : "", ",",
+                                 WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                 | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                 | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                 0, &num_tags);
 
     /* build string with tags and commas around: ",tag1,tag2,tag3," */
     length = 1 + strlen ((ptr_value) ? ptr_value : "") + 1 + 1;
@@ -1160,6 +1170,90 @@ end:
     TRIGGER_CALLBACK_CB_END(info);
 }
 
+/*
+ * Callback for an info hooked.
+ */
+
+char *
+trigger_callback_info_cb (const void *pointer, void *data,
+                          const char *info_name, const char *arguments)
+{
+    const char *ptr_info;
+    char *info;
+
+    TRIGGER_CALLBACK_CB_INIT(NULL);
+
+    TRIGGER_CALLBACK_CB_NEW_EXTRA_VARS;
+
+    /* add data in hashtable used for conditions/replace/command */
+    weechat_hashtable_set (extra_vars, "tg_info_name", info_name);
+    weechat_hashtable_set (extra_vars, "tg_arguments", arguments);
+    weechat_hashtable_set (extra_vars, "tg_info", "");
+
+    /* execute the trigger (conditions, regex, command) */
+    trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL);
+
+end:
+    ptr_info = weechat_hashtable_get (extra_vars, "tg_info");
+    info = (ptr_info) ? strdup (ptr_info) : NULL;
+
+    TRIGGER_CALLBACK_CB_END(info);
+}
+
+/*
+ * Callback for an info_hashtable hooked.
+ */
+
+struct t_hashtable *
+trigger_callback_info_hashtable_cb (const void *pointer, void *data,
+                                    const char *info_name,
+                                    struct t_hashtable *hashtable)
+{
+    struct t_hashtable *ret_hashtable;
+    struct t_weelist_item *ptr_item;
+    const char *ptr_key;
+
+    TRIGGER_CALLBACK_CB_INIT(NULL);
+
+    ret_hashtable = NULL;
+
+    TRIGGER_CALLBACK_CB_NEW_POINTERS;
+    TRIGGER_CALLBACK_CB_NEW_VARS_UPDATED;
+
+    extra_vars = weechat_hashtable_dup (hashtable);
+
+    /* add data in hashtable used for conditions/replace/command */
+    weechat_hashtable_set (extra_vars, "tg_info_name", info_name);
+
+    /* execute the trigger (conditions, regex, command) */
+    trigger_callback_execute (trigger, NULL, pointers, extra_vars,
+                              vars_updated);
+
+    ret_hashtable = weechat_hashtable_new (32,
+                                           WEECHAT_HASHTABLE_STRING,
+                                           WEECHAT_HASHTABLE_STRING,
+                                           NULL, NULL);
+    if (ret_hashtable)
+    {
+        /* copy updated variables into the result "ret_hashtable" */
+        for (ptr_item = weechat_list_get (vars_updated, 0); ptr_item;
+             ptr_item = weechat_list_next (ptr_item))
+        {
+            ptr_key = weechat_list_string (ptr_item);
+            if (weechat_hashtable_has_key (extra_vars, ptr_key))
+            {
+                weechat_hashtable_set (
+                    ret_hashtable,
+                    ptr_key,
+                    weechat_hashtable_get (extra_vars, ptr_key));
+            }
+        }
+    }
+
+end:
+    TRIGGER_CALLBACK_CB_END(ret_hashtable);
+}
+
 /*
  * Initializes trigger callback.
  */
