@@ -682,8 +682,11 @@ trigger_command_trigger (const void *pointer, void *data,
                 goto end;
             }
         }
-        items = weechat_string_split (trigger_hook_default_rc[type], ",", 0, 0,
-                                      &num_items);
+        items = weechat_string_split (trigger_hook_default_rc[type], ",",
+                                      WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                      | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                      | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                      0, &num_items);
         snprintf (input, sizeof (input),
                   "/trigger add name %s \"%s\" \"%s\" \"%s\" \"%s\"%s%s%s",
                   trigger_hook_type_string[type],
@@ -1154,7 +1157,7 @@ trigger_command_init ()
            " addreplace: add or replace an existing trigger\n"
            "       name: name of trigger\n"
            "       hook: signal, hsignal, modifier, line, print, command, "
-           "command_run, timer, config, focus\n"
+           "command_run, timer, config, focus, info, info_hashtable\n"
            "  arguments: arguments for the hook, depending on hook (separated "
            "by semicolons):\n"
            "             signal: name(s) of signal (required)\n"
@@ -1169,6 +1172,8 @@ trigger_command_init ()
            "             timer: interval (required), align on second, max calls\n"
            "             config: name(s) of option (required)\n"
            "             focus: name(s) of area (required)\n"
+           "             info: name(s) of info (required)\n"
+           "             info_hashtable: name(s) of info (required)\n"
            " conditions: evaluated conditions for the trigger\n"
            "      regex: one or more regular expressions to replace strings "
            "in variables\n"
@@ -1214,7 +1219,8 @@ trigger_command_init ()
            "  2. replace text using POSIX extended regular expression(s) (if "
            "defined in trigger)\n"
            "  3. execute command(s) (if defined in trigger)\n"
-           "  4. exit with a return code (except for modifier, line and focus)\n"
+           "  4. exit with a return code (except for modifier, line, focus, "
+           "info and info_hashtable)\n"
            "  5. perform post action\n"
            "\n"
            "Examples (you can also look at default triggers with /trigger "
